@@ -358,7 +358,7 @@ def rate_based_kn_candidates(
         # information to send
         dict_filt = {1: 'g', 2: 'r'}
         alert_text = """
-            *New kilonova candidate:* <http://134.158.75.151:24000/{}|{}>
+            *New kilonova candidate:* <https://fink-portal.org/{}|{}>
             """.format(alertID, alertID)
         score_text = """
             *Scores:*\n- Early SN Ia: {:.2f}\n- Ia SN vs non-Ia SN: {:.2f}\n- SN Ia and Core-Collapse vs non-SN: {:.2f}
